@@ -39,27 +39,27 @@ class UserAuthHelper:
 
         requestContext = event.get("requestContext")
         if requestContext is None:
-            self.logger.warning("request context is none")
+            self.logger.warning("NoContext", "request context is none")
             return None
 
         authorizer = requestContext.get("authorizer")
         if authorizer is None:
-            self.logger.warning("authorizer is none")
+            self.logger.warning("NoAuthorizer", "authorizer is none")
             return None
 
         claims = authorizer.get("claims")
         if claims is None:
-            self.logger.warning("claims is none")
+            self.logger.warning("NoClaims", "claims is none")
             return None
 
         email = claims.get("email")
         if (not isinstance(email, str)) or (email == ""):
-            self.logger.warning("email none, invalid type, or empty")
+            self.logger.warning("NoEmail", "email none, invalid type, or empty")
             return None
 
         sub = claims.get("sub")
         if (not isinstance(sub, str)) or (sub == ""):
-            self.logger.warning("sub none, invalid type, or empty")
+            self.logger.warning("NoSub", "sub none, invalid type, or empty")
             return None
 
         is_email_verified = claims.get("email_verified")
@@ -223,6 +223,23 @@ class UserAuthHelper:
 
         return properly_user_id
 
+    def get_properly_user_from_user_verified_email(self, email: str):
+        key_condition = Key("verifiedEmail").eq(email)
+
+        response = self.user_table.query(IndexName="verifiedEmail-index", KeyConditionExpression=key_condition,)
+        items = response.get("Items")
+        if len(items) > 1:
+            self.logger.error("more than one user associated with verified email: {}".format(email))
+
+        item = None
+        for item_candidate in items[:1]:
+            item = item_candidate  # use the first one found
+
+        if item is None:
+            return None
+
+        return DynamoData.to_dict(item)
+
     def get_properly_id_from_user_auth_email(self, auth_email: str):
 
         key_condition = Key("unverifiedEmail").eq(auth_email)
@@ -367,3 +384,24 @@ class UserAuthHelper:
         is_identity_match = user_record_cognito_id == sub
 
         return is_identity_match
+
+    def check_user_identity(self, user_dict: dict, sub: str, provider: str) -> bool:
+        cognito_id_key = "authIdCognitoGoogle" if provider == "Google" else "authIdCognito"
+        user_record_cognito_id = user_dict.get(cognito_id_key)
+
+        is_identity_match = user_record_cognito_id == sub
+
+        return is_identity_match
+
+    def check_user_in_role(self, user_dict: dict, role_id: str):
+        if role_id == UserAuthHelper.BASIC_ROLE_ID:
+            return True  # if the user exists they are automatically in the basic role
+
+        roles_array = user_dict.get(UserSchema.ROLES)
+
+        if roles_array is None:
+            return False
+
+        has_role_flag = role_id in roles_array
+
+        return has_role_flag
